@@ -1,7 +1,4 @@
 .onLoad = function(libname, pkgname){ 
-  # default options
-  evalq(opts_knit$set(kfigr.link = TRUE, kfigr.prefix = FALSE), 
-       envir=getNamespace('knitr'))
   anchorenv <- new.env(parent = getNamespace("kfigr"))
   assign("anchorenv", anchorenv, envir = getNamespace("kfigr"))
   assign("types", character(0), envir=anchorenv)
@@ -10,12 +7,18 @@
 }
 
 .onAttach = function(libname, pkgname){
+  # default options
+  evalq(opts_knit$set(kfigr.link = TRUE, kfigr.prefix = FALSE), 
+       envir=getNamespace('knitr'))
   # anchor hook definition
   evalq(knit_hooks$set(anchor = hook_anchor), envir = getNamespace('knitr'))
   packageStartupMessage('knitr hook "anchor" is now available')
 }
 
 .onDetach = function(libname){
+  # remove default options
+  evalq(opts_knit$set(kfigr.link = NULL, kfigr.prefix = NULL), 
+       envir=getNamespace('knitr'))
   # remove anchor hook definition
   evalq(knit_hooks$set(anchor = NULL), envir = getNamespace('knitr'))
   packageStartupMessage('knitr hook "anchor" has been removed')
